@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: build_templates.py 9979 2017-05-20 16:33:56Z Lavender $
+# $Id: build_templates.py 9980 2017-05-21 12:37:33Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,16 +12,19 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2017-05-21 00:33:56 +0800 (週日, 21 五月 2017) $
-# $Revision: 9979 $
+# $Date: 2017-05-21 20:37:33 +0800 (週日, 21 五月 2017) $
+# $Revision: 9980 $
 
 import os
 import sys
 import logging
+import shutil
 
 from django.core.management.base import BaseCommand, CommandError
+from django.conf import settings
 
-from Zephyrus.boilerplate.management.commands import TEMPLATES_DIR_PATH
+from Zephyrus.boilerplate.management.commands import (
+    TEMPLATES_DIR_PATH, ROOT_DIR_PATH)
 
 logger = logging.getLogger(__name__)
 logger.setLevel(logging.DEBUG)
@@ -46,6 +49,16 @@ class Command(BaseCommand):
 
         for f in os.listdir(startPath):
             tempPath = os.path.join(startPath, f)
+            
+            dbPath = settings.DATABASES['default']['NAME']
+            backupDbPath = os.path.join(ROOT_DIR_PATH, "backup.db")
+            if os.path.isfile(backupDbPath):
+                if os.path.isfile(dbPath):
+                    os.remove(dbPath)
+                shutil.copyfile(backupDbPath, dbPath)
+            else:
+                os.system("%s manage.py migrate" % sys.executable)
+                shutil.copyfile(dbPath, backupDbPath)
 
             # get_template
             error = os.system(
